@@ -5,11 +5,11 @@ use strict;
 use warnings;
 
 use Carp;
-use LWP;
+use Mojo::UserAgent;
 
 use vars qw($DEBUG $CACHE);
 
-our $VERSION = '0.11';
+our $VERSION = '1.01_01';
 
 our %searches = (
 	cities                              => 'cities?',
@@ -35,7 +35,7 @@ our %searches = (
 #	o	= optional
 #	rc	= required - only one of the fields marked with rc is allowed. At least one must be present
 #	om	= optional, multiple entries allowed
-#	d	= depreciated - will be removed in later versions
+#	d	= deprecated - will be removed in later versions
 our %valid_parameters = (
 	search => {
 		'q'    => 'rc',
@@ -209,10 +209,10 @@ sub url {
 	$self->{url};
 	}
 
-sub _build_request {
+sub _build_request_url {
 	my( $self, $request, @args ) = @_;
 	my $hash = { @args, username => $self->username };
-	my $request_string = $self->url . '/' . $searches{$request};
+	my $request_url = $self->url . '/' . $searches{$request};
 
 	# check to see that mandatory arguments are present
 	my $conditional_mandatory_flag = 0;
@@ -220,7 +220,7 @@ sub _build_request {
 	foreach my $arg (keys %{$valid_parameters{$request}}) {
 		my $flags = $valid_parameters{$request}->{$arg};
 		if($flags =~ /d/ && exists($hash->{$arg})) {
-			carp("Argument $arg is depreciated.");
+			carp("Argument $arg is deprecated.");
 			}
 		$flags =~ s/d//g;
 		if($flags eq 'r' && !exists($hash->{$arg})) {
@@ -245,11 +245,11 @@ sub _build_request {
 		carp("Invalid argument $key") if(!defined($valid_parameters{$request}->{$key}));
 		my @vals = ref($hash->{$key}) ? @{$hash->{$key}} : $hash->{$key};
 		no warnings 'uninitialized';
-		$request_string .= join("", map { "$key=$_&" } @vals );
+		$request_url .= join("", map { "$key=$_&" } @vals );
 		}
 
-	chop($request_string); # loose the trailing &
-	return $request_string;
+	chop($request_url); # loose the trailing &
+	return $request_url;
 	}
 
 sub _parse_xml_result {
@@ -316,41 +316,44 @@ sub _parse_text_result {
 	}
 
 sub _request {
-	my( $self, $request ) = @_;
-	my $browser = LWP::UserAgent->new;
-	$browser->env_proxy();
-	my $response = $browser->get($request);
-	carp "Can't get $request -- ", $response->status_line
-		unless $response->is_success;
-	return $response;
+	my( $self, $request_url ) = @_;
+	state $ua = do {
+		my $ua = Mojo::UserAgent->new;
+		$ua->on( error => sub { carp "Can't get request" } );
+		$ua;
+		};
+
+	$ua->get( $request_url )->res;
 	}
 
 sub _do_search {
 	my( $self, $searchtype, @args ) = @_;
 
-	my $request = $self->_build_request( $searchtype, @args );
-	my $response = $self->_request( $request );
+	my $request_url = $self->_build_request_url( $searchtype, @args );
+	my $response = $self->_request( $request_url );
 
 	# check mime-type to determine which parse method to use.
 	# we accept text/xml, text/plain (how do see if it is JSON or not?)
-	my $mime_type = $response->header( 'Content-type' );
+	my $mime_type = $response->headers->content_type || '';
+
 	if($mime_type =~ m(\Atext/xml;) ) {
-		return $self->_parse_xml_result( $response->content );
+		return $self->_parse_xml_result( $response->body );
 		}
 	if($mime_type =~ m(\Aapplication/json;) ) {
 		# a JSON object always start with a left-brace {
 		# according to http://json.org/
-		if( $response->content =~ m/\A\{/ ) {
-			return $self->_parse_json_result( $response->content );
+		my $body = $response->body;
+		if( $body =~ m/\A\{/ ) {
+			return $response->json
 			}
 		else {
-			return $self->_parse_text_result( $response->content );
+			return $self->_parse_text_result( $body );
 			}
 		}
 
-	carp "Invalid mime type [$mime_type]";
+	carp "Invalid mime type [$mime_type]. Maybe you aren't connected.";
 
-	return;
+	return [];
 	}
 
 sub geocode {
@@ -488,7 +491,7 @@ as follows:
 One, and only one, of B<q>, B<name>, or B<name_equals> must be
 supplied to this function.
 
-fclass is depreciated.
+fclass is deprecated.
 
 For a thorough description of the arguments, see
 http://www.geonames.org/export/geonames-search.html
